summaryrefslogtreecommitdiff
path: root/Master/tlpkg/TeXLive/TLPaper.pm
diff options
context:
space:
mode:
authorNorbert Preining <preining@logic.at>2016-04-15 23:52:45 +0000
committerNorbert Preining <preining@logic.at>2016-04-15 23:52:45 +0000
commitc861b47a77d1d1b447cefc6843cf8807852c30cf (patch)
tree99ba5d2749bb096fbc0492867d42d8da95ec1d48 /Master/tlpkg/TeXLive/TLPaper.pm
parent092d3631df923d75af27fc722762379e14afc3e9 (diff)
fix for (again) new pdftex config files format
git-svn-id: svn://tug.org/texlive/trunk@40542 c570f23f-e606-0410-a88d-b1316a301751
Diffstat (limited to 'Master/tlpkg/TeXLive/TLPaper.pm')
-rw-r--r--Master/tlpkg/TeXLive/TLPaper.pm20
1 files changed, 10 insertions, 10 deletions
diff --git a/Master/tlpkg/TeXLive/TLPaper.pm b/Master/tlpkg/TeXLive/TLPaper.pm
index 0b81e4e2f4b..b721566ff2f 100644
--- a/Master/tlpkg/TeXLive/TLPaper.pm
+++ b/Master/tlpkg/TeXLive/TLPaper.pm
@@ -1,6 +1,6 @@
# $Id: TLPaper.pm 39006 2015-12-03 18:53:45Z karl $
# TeXLive::TLPaper.pm - query/modify paper sizes for our various programs
-# Copyright 2008-2015 Norbert Preining
+# Copyright 2008-2016 Norbert Preining
# This file is licensed under the GNU General Public License version 2
# or any later version.
#
@@ -62,7 +62,7 @@ our %paper = (
"pdftex" => {
sub => \&paper_pdftex,
default_component => "tex/generic/config",
- default_file => "pdftexconfig.dat",
+ default_file => "pdftexconfig.tex",
pkg => "pdftex",
},
"dvips" => {
@@ -298,8 +298,8 @@ sub paper_xdvi {
# pdftex pdftexconfig.dat format
# /--- pdftexconfig.tex ---
# |...
# |pageheight = 297 true mm
# |pagewidth = 210 true mm
# |...
# \------------------------
#
@@ -327,7 +327,7 @@ sub paper_pdftex {
# read the lines and the last pdfpageswidth/height wins
for my $idx (0..$#lines) {
my $l = $lines[$idx];
- if ($l =~ m/^\s*pagewidth\s*=\s*([0-9.,]+\s*true\s*[^\s]*)/) {
+ if ($l =~ m/^\s*\\pdfpagewidth\s*=\s*([0-9.,]+\s*true\s*[^\s]*)/) {
if (defined($cpw) && $cpw ne $1) {
tl_warn("TLPaper: inconsistent paper sizes in $inp for page width! Please fix that.\n");
return $F_ERROR;
@@ -336,7 +336,7 @@ sub paper_pdftex {
push @cpwidx, $idx;
next;
}
- if ($l =~ m/^\s*pageheight\s*=\s*([0-9.,]+\s*true\s*[^\s]*)/) {
+ if ($l =~ m/^\s*\\pdfpageheight\s*=\s*([0-9.,]+\s*true\s*[^\s]*)/) {
if (defined($cph) && $cph ne $1) {
tl_warn("TLPaper: inconsistent paper sizes in $inp for page height! Please fix that.\n");
return $F_ERROR;
@@ -393,11 +393,11 @@ sub paper_pdftex {
for my $idx (@cpwidx) {
ddebug("TLPaper: before line: $lines[$idx]");
ddebug("TLPaper: replacement: $newwidth\n");
- $lines[$idx] =~ s/^\s*pagewidth\s*=\s*[0-9.,]+\s*true\s*[^\s]*/pagewidth = $newwidth/;
+ $lines[$idx] =~ s/^\s*\\pdfpagewidth\s*=\s*[0-9.,]+\s*true\s*[^\s]*/pagewidth = $newwidth/;
ddebug("TLPaper: after line : $lines[$idx]");
}
} else {
- my $addlines = "pagewidth = $newwidth\n";
+ my $addlines = "\\pdfpagewidth = $newwidth\n";
if (defined($endinputidx)) {
$lines[$endinputidx] = $addlines . $lines[$endinputidx];
} else {
@@ -408,11 +408,11 @@ sub paper_pdftex {
for my $idx (@cphidx) {
ddebug("TLPaper: before line: $lines[$idx]");
ddebug("TLPaper: replacement: $newheight\n");
- $lines[$idx] =~ s/pageheight\s*=\s*[0-9.,]+\s*true\s*[^\s]*/pageheight = $newheight/;
+ $lines[$idx] =~ s/^\s*\\pdfpageheight\s*=\s*[0-9.,]+\s*true\s*[^\s]*/pageheight = $newheight/;
ddebug("TLPaper: after line : $lines[$idx]");
}
} else {
- my $addlines = "pageheight = $newheight";
+ my $addlines = "\\pdfpageheight = $newheight";
if (defined($endinputidx)) {
$lines[$endinputidx] = $addlines . $lines[$endinputidx];
} else {
@@ -298,8 +298,8 @@ sub paper_xdvi {
# /--- pdftexconfig.tex ---
# |...
-# |pageheight = 297 true mm
-# |pagewidth = 210 true mm
+# |\pdfpageheight = 297 true mm
+# |\pdfpagewidth = 210 true mm
# |...
# \------------------------